@@ -226,8 +226,8 @@ class UncertainFunction(object):
         Optional
         --------
         hist : bool
-            If true, a histogram is displayed
-        kwargs : any valid matplotlib.pyplot.plot kwarg
+            If true, a density histogram is displayed (histtype='stepfilled')
+        kwargs : any valid matplotlib.pyplot.plot or .hist kwarg
         
         """
         vals = self._mcpts
@@ -237,23 +237,29 @@ class UncertainFunction(object):
         p = ss.kde.gaussian_kde(vals)
         xp = np.linspace(low,high,100)
 
-        plt.figure()
+#        plt.figure()
         if hist:
-            plt.hist(vals, bins=np.round(np.sqrt(vals)), histtype='stepfilled',
-                **kwargs)
+            h = plt.hist(vals, bins=np.round(np.sqrt(len(vals))), 
+                     histtype='stepfilled', normed=True, **kwargs)
             if self.tag is not None:
-                plt.title('Histogram of ('+self.tag+') - '+str(self))
+                plt.suptitle('Histogram of ('+self.tag+')')
+                plt.title(str(self), fontsize=12)
             else:
-                plt.title('Histogram of '+str(self))
+                plt.suptitle('Histogram of')
+                plt.title(str(self), fontsize=12)
+            plt.ylim(0, 1.1*h[0].max())
         else:
             plt.plot(xp,p.evaluate(xp))
             if self.tag is not None:
-                plt.title('KDE of ('+self.tag+') - '+str(self))
+                plt.suptitle('KDE of ('+self.tag+')')
+                plt.title(str(self), fontsize=12)
             else:
-                plt.title('KDE of '+str(self))
+                plt.suptitle('KDE of')
+                plt.title(str(self), fontsize=12)
 
         plt.xlim(low - (high - low)*0.1, high + (high - low)*0.1)
-        plt.ylim(ymin=0)
+
+    def show(self):
         plt.show()
 
     def __add__(self, val):
@@ -387,28 +393,42 @@ class UncertainVariable(UncertainFunction):
     for creating UncertainVariable objects using some of the most common 
     statistical distributions:
     
-    =========================  ============  ==================  ====  ========
-    Distribution               scipy.stats   args                loc   scale
-                               class name    (shape parameters)
-    =========================  ============  ==================  ====  ========
-    Normal(mu, sigma)          norm                              mu    sigma
-    Uniform(a, b)              uniform                           a     b-a
-    Exponential(lamda)         expon                                   1/lambda
-    Gamma(k, theta)            gamma         k                         theta
-    Beta(alpha, beta, [a, b])  beta          alpha, beta         a     b-a
-    Log-Normal(mu, sigma)      lognorm       sigma               mu
-    Chi-Square(k)              chi2          k
-    F(d1, d2)                  f             d1, d2
-    Triangular(a, b, c)        triang        c                   a     b-a
-    Student-T(v)               t             v
-    Weibull(lamda, k)          exponweib     lamda, k
-    =========================  ============  =================== ====  ========
-    Bernoulli(p)               bernoulli     p
-    Binomial(n, p)             binomial      n, p
-    Geometric(p)               geom          p
-    Hypergeometric(M, n, N)    hypergeom     M, n, N
-    Poisson(lamda)             poisson       lamda
-    =========================  ============  =================== ====  ========
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Distribution              | scipy.stats |  args             | loc | scale   |
+    |                           | class name  | (shape params)    |     |         |
+    +===========================+=============+===================+=====+=========+
+    | Normal(mu, sigma)         | norm        |                   | mu  | sigma   | 
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Uniform(a, b)             | uniform     |                   | a   | b-a     |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Exponential(lamda)        | expon       |                   |     | 1/lamda |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Gamma(k, theta)           | gamma       | k                 |     | theta   |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Beta(alpha, beta, [a, b]) | beta        | alpha, beta       | a   | b-a     |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Log-Normal(mu, sigma)     | lognorm     | sigma             | mu  |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Chi-Square(k)             | chi2        | k                 |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | F(d1, d2)                 | f           | d1, d2            |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Triangular(a, b, c)       | triang      | c                 | a   | b-a     |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Student-T(v)              | t           | v                 |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Weibull(lamda, k)         | exponweib   | lamda, k          |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Bernoulli(p)              | bernoulli   | p                 |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Binomial(n, p)            | binomial    | n, p              |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Geometric(p)              | geom        | p                 |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Hypergeometric(M, n, N)   | hypergeom   | M, n, N           |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
+    | Poisson(lamda)            | poisson     | lamda             |     |         |
+    +---------------------------+-------------+-------------------+-----+---------+
     
     Thus, each distribution above would have the same call signature::
         
@@ -422,27 +442,46 @@ class UncertainVariable(UncertainFunction):
     distributions easier. They follow the parameter notation found in the
     respective Wikipedia articles:
     
-    ===========================  ===========================================
-    MCERP Distibution            Wikipedia page
-    ===========================  ===========================================
-    N(mu, sigma)                 http://en.wikipedia.org/wiki/Normal_distribution
-    U(a, b)                      http://en.wikipedia.org/wiki/Uniform_distribution_(continuous)
-    Exp(lamda, [mu])             http://en.wikipedia.org/wiki/Exponential_distribution
-    Gamma(k, theta)              http://en.wikipedia.org/wiki/Gamma_distribution
-    Beta(alpha, beta, [a, b])    http://en.wikipedia.org/wiki/Beta_distribution
-    LogN(mu, sigma)              http://en.wikipedia.org/wiki/Log-normal_distribution
-    X2(df)                       http://en.wikipedia.org/wiki/Chi-squared_distribution
-    F(dfn, dfd)                  http://en.wikipedia.org/wiki/F-distribution
-    Tri(a, b, c)                 http://en.wikipedia.org/wiki/Triangular_distribution
-    T(df)                        http://en.wikipedia.org/wiki/Student's_t-distribution
-    Weib(lamda, k)               http://en.wikipedia.org/wiki/Weibull_distribution
-    ===========================  ===========================================
-    Bern(p)                      http://en.wikipedia.org/wiki/Bernoulli_distribution
-    B(n, p)                      http://en.wikipedia.org/wiki/Binomial_distribution
-    G(p)                         http://en.wikipedia.org/wiki/Geometric_distribution
-    H(M, n, N)                   http://en.wikipedia.org/wiki/Hypergeometric_distribution
-    Pois(lamda)                  http://en.wikipedia.org/wiki/Poisson_distribution
-    ===========================  ===========================================
+    +---------------------------+---------------------------------------------------------------+
+    | MCERP Distibution         | Wikipedia page                                                |
+    +===========================+===============================================================+
+    | N(mu, sigma)              | http://en.wikipedia.org/wiki/Normal_distribution              |
+    +---------------------------+---------------------------------------------------------------+
+    | U(a, b)                   | http://en.wikipedia.org/wiki/Uniform_distribution_(continuous)|
+    +---------------------------+---------------------------------------------------------------+
+    | Exp(lamda, [mu])          | http://en.wikipedia.org/wiki/Exponential_distribution         |
+    +---------------------------+---------------------------------------------------------------+
+    | Gamma(k, theta)           | http://en.wikipedia.org/wiki/Gamma_distribution               |
+    +---------------------------+---------------------------------------------------------------+
+    | Beta(alpha, beta, [a, b]) | http://en.wikipedia.org/wiki/Beta_distribution                |
+    +---------------------------+---------------------------------------------------------------+
+    | LogN(mu, sigma)           | http://en.wikipedia.org/wiki/Log-normal_distribution          |
+    +---------------------------+---------------------------------------------------------------+
+    | X2(df)                    | http://en.wikipedia.org/wiki/Chi-squared_distribution         |
+    +---------------------------+---------------------------------------------------------------+
+    | F(dfn, dfd)               | http://en.wikipedia.org/wiki/F-distribution                   |
+    +---------------------------+---------------------------------------------------------------+
+    | Tri(a, b, c)              | http://en.wikipedia.org/wiki/Triangular_distribution          |
+    +---------------------------+---------------------------------------------------------------+
+    | T(df)                     | http://en.wikipedia.org/wiki/Student's_t-distribution         |
+    +---------------------------+---------------------------------------------------------------+
+    | Weib(lamda, k)            | http://en.wikipedia.org/wiki/Weibull_distribution             |
+    +---------------------------+---------------------------------------------------------------+
+    | Bern(p)                   | http://en.wikipedia.org/wiki/Bernoulli_distribution           |
+    +---------------------------+---------------------------------------------------------------+
+    | B(n, p)                   | http://en.wikipedia.org/wiki/Binomial_distribution            |
+    +---------------------------+---------------------------------------------------------------+
+    | G(p)                      | http://en.wikipedia.org/wiki/Geometric_distribution           |
+    +---------------------------+---------------------------------------------------------------+
+    | H(M, n, N)                | http://en.wikipedia.org/wiki/Hypergeometric_distribution      |
+    +---------------------------+---------------------------------------------------------------+
+    | Pois(lamda)               | http://en.wikipedia.org/wiki/Poisson_distribution             |
+    +---------------------------+---------------------------------------------------------------+
+
+    Thus, the following are equivalent::
+
+        >>> x = N(10, 1)
+        >>> x = uv(ss.norm(loc=10, scale=1))
 
     Examples
     --------
@@ -562,37 +601,49 @@ xt, this parameter should be changed before any
         
         if hist:
             vals = self._mcpts
-            plt.hist(vals, bins=np.round(np.sqrt(vals)), histtype='stepfilled',
-                **kwargs)
+            low = vals.min()
+            high = vals.max()
+            h = plt.hist(vals, bins=np.round(np.sqrt(len(vals))), 
+                     histtype='stepfilled', normed=True, **kwargs)
 
             if self.tag is not None:
-                plt.title('Histogram of ('+self.tag+') - '+str(self))
+                plt.suptitle('Histogram of (' + self.tag + ')')
+                plt.title(str(self), fontsize=12)
             else:
-                plt.title('Histogram of '+str(self))
+                plt.suptitle('Histogram of')
+                plt.title(str(self), fontsize=12)
 
+            plt.ylim(0, 1.1*h[0].max())
         else:
-            low = int(self.rv.ppf(1e-6))
-            high = int(self.rv.ppf(1 - 1e-6))
+            bound = 1e-6
+            low = self.rv.ppf(bound)
+            high = self.rv.ppf(1 - bound)
             if hasattr(self.rv.dist, 'pmf'):
+                low = int(low)
+                high = int(high)
                 vals = range(low, high + 1)
                 plt.plot(vals, self.rv.pmf(vals), 'o', **kwargs)
 
                 if self.tag is not None:
-                    plt.title('PMF of ('+self.tag+') - '+str(self))
+                    plt.suptitle('PMF of (' + self.tag + ')')
+                    plt.title(str(self), fontsize=12)
                 else:
-                    plt.title('PMF of '+str(self))
+                    plt.suptitle('PMF of')
+                    plt.title(str(self), fontsize=12)
 
             else:
                 vals = np.linspace(low, high, 500)
                 plt.plot(vals, self.rv.pdf(vals), **kwargs)
 
                 if self.tag is not None:
-                    plt.title('PDF of ('+self.tag+') - '+str(self))
+                    plt.suptitle('PDF of ('+self.tag+')')
+                    plt.title(str(self), fontsize=12)
                 else:
-                    plt.title('PDF of '+str(self))
+                    plt.suptitle('PDF of')
+                    plt.title(str(self), fontsize=12)
 
         plt.xlim(low - (high - low)*0.1, high + (high - low)*0.1)
-        plt.show()
+
                 
         
 uv = UncertainVariable # a nicer form for the user
@@ -605,7 +656,7 @@ uv = UncertainVariable # a nicer form for the user
 
 def N(mu, sigma, tag=None):
     """
-    A normal random variate
+    A Normal (or Gaussian) random variate
     
     Parameters
     ----------
@@ -621,7 +672,7 @@ def N(mu, sigma, tag=None):
 
 def U(a, b, tag=None):
     """
-    A uniform random variate
+    A Uniform random variate
     
     Parameters
     ----------
@@ -637,7 +688,7 @@ def U(a, b, tag=None):
 
 def Exp(lamda, mu=None, tag=None):
     """
-    An exponential random variate
+    An Exponential random variate
     
     Parameters
     ----------
@@ -660,7 +711,7 @@ def Exp(lamda, mu=None, tag=None):
 
 def Gamma(k, theta, tag=None):
     """
-    A gamma random variate
+    A Gamma random variate
     
     Parameters
     ----------
@@ -676,7 +727,7 @@ def Gamma(k, theta, tag=None):
 
 def Beta(alpha, beta, a=0, b=1, tag=None):
     """
-    A beta random variate
+    A Beta random variate
     
     Parameters
     ----------
@@ -699,7 +750,7 @@ def Beta(alpha, beta, a=0, b=1, tag=None):
 
 def LogN(mu, sigma, tag=None):
     """
-    A log-normal random variate
+    A Log-Normal random variate
     
     Parameters
     ----------
@@ -715,7 +766,7 @@ def LogN(mu, sigma, tag=None):
 
 def X2(k, tag=None):
     """
-    An Chi-Squared random variate
+    A Chi-Squared random variate
     
     Parameters
     ----------
@@ -764,7 +815,7 @@ def Tri(a, b, c, tag=None):
 
 def T(v, tag=None):
     """
-    An Student-T random variate
+    A Student-T random variate
     
     Parameters
     ----------
@@ -778,7 +829,7 @@ def T(v, tag=None):
 
 def Weib(lamda, k, tag=None):
     """
-    An Weibull random variate
+    A Weibull random variate
     
     Parameters
     ----------
@@ -794,7 +845,7 @@ def Weib(lamda, k, tag=None):
 
 def Bern(p, tag=None):
     """
-    An Bernoulli random variate
+    A Bernoulli random variate
     
     Parameters
     ----------
@@ -808,7 +859,7 @@ def Bern(p, tag=None):
 
 def B(n, p, tag=None):
     """
-    An Binomial random variate
+    A Binomial random variate
     
     Parameters
     ----------
@@ -825,7 +876,7 @@ def B(n, p, tag=None):
 
 def G(p, tag=None):
     """
-    An Geometric random variate
+    A Geometric random variate
     
     Parameters
     ----------
@@ -839,7 +890,7 @@ def G(p, tag=None):
 
 def H(p, tag=None):
     """
-    An Hypergeometric random variate
+    A Hypergeometric random variate
     
     Parameters
     ----------
@@ -859,7 +910,7 @@ def H(p, tag=None):
 
 def Pois(lamda, tag=None):
     """
-    An Poisson random variate
+    A Poisson random variate
     
     Parameters
     ----------
